@@ -10,15 +10,21 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from keystoneauth1.identity.v3.application_credential import *  # noqa
 from keystoneauth1.identity.v3.base import *  # noqa
 from keystoneauth1.identity.v3.federation import *  # noqa
 from keystoneauth1.identity.v3.k2k import *  # noqa
+from keystoneauth1.identity.v3.oidc import *  # noqa
 from keystoneauth1.identity.v3.password import *  # noqa
 from keystoneauth1.identity.v3.token import *  # noqa
-from keystoneauth1.identity.v3.oidc import *  # noqa
+from keystoneauth1.identity.v3.totp import *  # noqa
+from keystoneauth1.identity.v3.tokenless_auth import *  # noqa
 
 
-__all__ = ('Auth',
+__all__ = ('ApplicationCredential',
+           'ApplicationCredentialMethod',
+
+           'Auth',
            'AuthConstructor',
            'AuthMethod',
            'BaseAuth',
@@ -33,5 +39,12 @@ __all__ = ('Auth',
            'Token',
            'TokenMethod',
 
+           'OidcAccessToken',
            'OidcAuthorizationCode',
-           'OidcPassword',)
+           'OidcClientCredentials',
+           'OidcPassword',
+
+           'TOTPMethod',
+           'TOTP',
+
+           'TokenlessAuth')
